local mod = ...



-- Masterpiece conditions ------------------------------------------------------------------------------------

-- Gem Encrusted Cross
-- keep same vanilla conditions (50 splendor in a single clergy monument)

-- Officinal Garden
-- keep the same vanilla conditions (wounded and dead soldiers)

-- Stained Glass
-- keep the same vanilla conditions (50 clergy influence)

-- Knight statue
-- keep the same vanilla conditions (win the hardest battle with the same army)

-- Sculpture Fountain
mod:overrideAsset({
    Id = "MASTERPIECE_SCULPTURE_FOUNTAIN",
    UnlockCondition = {
        DataType = "GAME_CONDITION_VILLAGER_STATUS_REACHED",
        AssetVillagerStatus = "SERF",
        NumberRequired = 100,
    },
})

-- Automated Fountain
mod:overrideAsset({
    Id = "MASTERPIECE_AUTOMATE_FOUNTAIN",
    UnlockCondition = {
        DataType = "GAME_CONDITION_VILLAGER_STATUS_REACHED",
        AssetVillagerStatus = "SERF",
        NumberRequired = 150,
    },
})

-- Lush Garden
mod:overrideAsset({
    Id = "MASTERPIECE_LUSH_GARDEN",
    UnlockCondition = {
        DataType = "GAME_CONDITION_VILLAGER_STATUS_REACHED",
        AssetVillagerStatus = "SERF",
        NumberRequired = 200,
    },
})

-- Shrine
mod:overrideAsset({
    Id = "MASTERPIECE_SHRINE",
    UnlockCondition = {
        DataType = "GAME_CONDITION_VILLAGER_STATUS_REACHED",
        AssetVillagerStatus = "SERF",
        NumberRequired = 250,
    },
})

-- Giant Gate
mod:overrideAsset({
    Id = "MASTERPIECE_GATE",
    UnlockCondition = {
        DataType = "GAME_CONDITION_VILLAGER_STATUS_REACHED",
        AssetVillagerStatus = "SOLDIER_KNIGHT",
        NumberRequired = 2,
    },
    EffectList = {
        {
            DataType = "GAME_RULE_MODIFIER_MILITARY_TRAINING",
            XPBonusPercentage = 0.20,
        },
    },
})



-- Milestones: Kingdom ------------------------------------------------------------------------------------
local reward1 =                                     {
    DataType = "QUEST_REWARD_RESOURCES",
    BudgetCategory = "QUESTS",
    ResourceCollection = {
        {
            Resource = "GOLD_COINS",
            Quantity = 300
        },
        {
            Resource = "BREAD",
            Quantity = 50
        },
        {
            Resource = "BOAR",
            Quantity = 20
        },
    },
}

local reward2 =                                     {
    DataType = "QUEST_REWARD_RESOURCES",
    BudgetCategory = "QUESTS",
    ResourceCollection = {
        {
            Resource = "GOLD_COINS",
            Quantity = 400
        },
        {
            Resource = "CHEESE",
            Quantity = 100
        },
        {
            Resource = "CLOTHES",
            Quantity = 50
        },
    },
}

local reward3 = {
    DataType = "QUEST_REWARD_RESOURCES",
    BudgetCategory = "QUESTS",
    ResourceCollection = {
        {
            Resource = "GOLD_COINS",
            Quantity = 500
        },
        {
            Resource = "FISH",
            Quantity = 200
        },
        {
            Resource = "CANDLE",
            Quantity = 100
        },
    },
}


local function registerMilestoneKingdom(id, stat, pop, inf, rew)
    mod:registerAsset({
        DataType = "EVENT",
        Id = "EVENT_IAE_MILESTONE_" .. id,
        DaysToFirst = 1,
        ConditionList = {
            {
                DataType = "GAME_CONDITION_VILLAGER_STATUS_REACHED",
                AssetVillagerStatus = stat,
                NumberRequired = pop
            }
        },
        ActionList = {
            {
                DataType = "ACTION_SHOW_NARRATIVE_PANEL",
                NarrativePanelData = {
                    Title = "EVENT_IAE_MILESTONE_" .. id .. "_NAME",
                    Description = "EVENT_IAE_MILESTONE_" .. id .. "_DESC",
                    PanelVisual = "ILLUSTRATION_ESTATE_KING",
                },
                ChoiceList = {
                    {
                        ShortName = "TEXT_IAE_OK",
                        EventActionList = {
                            {
                                DataType = "EVENT_ACTION_GIVE_REWARD",
                                ActionList = {
                                    rew,
                                    {
                                        DataType = "GAME_ACTION_GIVE_TERRITORY",
                                        Amount = 1,
                                    },
                                    {
                                        DataType = "GAME_ACTION_GIVE_INFLUENCE",
                                        EstateInfluence = {
                                            Estate = "KINGDOM",
                                            Quantity = inf,
                                        },
                                    },
                                },
                            },
                        },
                    },
                },
            },
        }
    })

    mod:overrideAsset({
        Id = "DEFAULT_BALANCING",
        EventList = {
            Action = "APPEND",
            "EVENT_IAE_MILESTONE_" .. id,
        },
    })

end

registerMilestoneKingdom("1", "SERF", 100, 10, reward1)
registerMilestoneKingdom("2", "SERF", 200, 10, reward2)
registerMilestoneKingdom("3", "SERF", 300, 10, reward3)


-- mod:registerAsset({
--     DataType = "EVENT",
--     Id = "EVENT_IAE_MILESTONE_0",
--     DaysToFirst = 1,
--     ConditionList = {
--         {
--             DataType = "GAME_CONDITION_VILLAGER_STATUS_REACHED",
--             AssetVillagerStatus = "NEWCOMER",
--             NumberRequired = 30,
--         }
--     },
--     ActionList = {
--         {
--             DataType = "ACTION_SHOW_NARRATIVE_PANEL",
--             NarrativePanelData = {
--                 Title = "EVENT_IAE_MILESTONE_0_NAME",
--                 Description = "EVENT_IAE_MILESTONE_0_DESC",
--                 PanelVisual = "ILLUSTRATION_ESTATE_KING",
--             },
--             ChoiceList = {
--                 {
--                     ShortName = "TEXT_IAE_OK",
--                     EventActionList = {
--                         {
--                             DataType = "EVENT_ACTION_GIVE_REWARD",
--                             ActionList = {
--                                 {
--                                     DataType = "GAME_ACTION_GIVE_TERRITORY",
--                                     Amount = 1,
--                                 },
--                             },
--                         },
--                     },
--                 },
--             },
--         },
--     }
-- })


-- mod:overrideAsset({
--     Id = "DEFAULT_BALANCING",
--     EventList = {
--         Action = "APPEND",
--         "EVENT_IAE_MILESTONE_0",
--     },
-- })




-- Milestones: Clergy ------------------------------------------------------------------------------------
local function registerMilestoneClergy(id, build, inf)
    mod:registerAsset({
        DataType = "EVENT",
        Id = "EVENT_IAE_MILESTONE_" .. id,
        DaysToFirst = 1,
        ConditionList = {
            {
                DataType = "GAME_CONDITION_BUILDING_BUILT",
                AssetBuilding = build,
            }
        },
        ActionList = {
            {
                DataType = "ACTION_SHOW_NARRATIVE_PANEL",
                NarrativePanelData = {
                    Title = "EVENT_IAE_MILESTONE_" .. id .. "_NAME",
                    Description = "EVENT_IAE_MILESTONE_" .. id .. "_DESC",
                    PanelVisual = "ILLUSTRATION_ESTATE_CHURCH",
                },
                ChoiceList = {
                    {
                        ShortName = "TEXT_IAE_OK",
                        EventActionList = {
                            {
                                DataType = "EVENT_ACTION_GIVE_REWARD",
                                ActionList = {
                                    {
                                        DataType = "GAME_ACTION_GIVE_INFLUENCE",
                                        EstateInfluence = {
                                            Estate = "CLERGY",
                                            Quantity = inf,
                                        },
                                    },
                                },
                            },
                        },
                    },
                },
            },
        }
    })

    mod:overrideAsset({
        Id = "DEFAULT_BALANCING",
        EventList = {
            Action = "APPEND",
            "EVENT_IAE_MILESTONE_" .. id,
        },
    })

end

registerMilestoneClergy("4", "MONUMENT_RUSTIC_CHURCH", 10)
registerMilestoneClergy("5", "MONUMENT_LEGACY_RUSTIC_CHURCH", 10)
registerMilestoneClergy("6", "MONUMENT_ROMAN_CHURCH", 10)
registerMilestoneClergy("7", "MONUMENT_CHURCH", 20)



